sleep-after
-----------

A simple python script to put your system to sleep/suspend

Uses
----
`pm-suspend` system tool

Usage
-----
`sleep-after 10`

This will put your system to sleep after 10 minutes.
Time interval argument is always in minutes.

Installation
------------
Please install it in your system and not in a virtual environment.
`pm-suspend` tool requires root previlages to execute, so installing
this in a virtualenv wont work.

`pip install sleep-after`

Developers
----------
Alfred Dominic

